@@ -3,15 +3,16 @@ import json
 import logging
 from argparse import Namespace, _SubParsersAction
 from enum import Enum
-from json import JSONDecodeError
 from typing import Any, Callable, Dict, Union
+
 import certifi
 import requests
+from requests import Response
 from requests.auth import AuthBase
+
 from a28 import utils
 from a28.config import ConfigFile
 
-
 logging.getLogger('requests').setLevel(logging.WARNING)
 logging.getLogger('urllib3').setLevel(logging.WARNING)
 log = logging.getLogger(__name__)
@@ -32,7 +33,10 @@ class ApiError(Exception):
     pass
 
 
-def parse_api_errors(response: Dict[str, Any], http_status_code: int) -> Dict[str, Any]:
+def parse_api_errors(
+    response: Dict[str, Any],
+    http_status_code: int
+) -> Dict[str, Any]:
     """Raise error if API returned errors or invalid data."""
     if response.get('status') == ApiStatus.SUCCESS:
         return response
@@ -47,13 +51,16 @@ def handle_api_errors(api_call) -> Callable:
     """Handle API error with a decorator."""
 
     def wrapper(*arg, **kwargs) -> Dict[str, Any]:
-        """Process api response, check for errors and raise ApiError if any."""
+        """Process api response.
+
+        check for errors and raise ApiError if any.
+        """
         try:
             response = api_call(*arg, **kwargs)
             response_payload = json.loads(response.content)
 
             return parse_api_errors(response_payload, response.status_code)
-        except JSONDecodeError as err:
+        except json.JSONDecodeError as err:
             raise ApiError(f'Unknown Error: {err}')
 
     return wrapper
@@ -73,11 +80,10 @@ class JwtAuth(AuthBase):
 
 
 class API:
-    """
-    Handles all the actions to the API.
+    """Handles all the actions to the API.
 
-    A region must be given to each instance so we can request to the correct API
-    (international, china, etc..)
+    A region must be given to each instance so we can request to the
+    correct API (international, china, etc..).
     """
 
     ENDPOINTS_URL = 'https://assets.a28.io/plugin/endpoints.json'
@@ -99,13 +105,20 @@ class API:
         self.session.hooks['response'].append(self._check_token)
 
     @handle_api_errors
-    def get(self, url: str, **kwargs) -> requests.Response:
+    def get(self, url: str, **kwargs) -> Response:
         """Send a GET request."""
+        url = f'{self.api_endpoint}{url}'
         kwargs.setdefault('allow_redirects', True)
-        return self.session.request('GET', f'{self.api_endpoint}{url}', **kwargs)
+        return self.session.request('GET', url, **kwargs)
 
     @handle_api_errors
-    def post(self, url: str, data=None, json_payload=None, **kwargs) -> requests.Response:
+    def post(
+        self,
+        url: str,
+        data=None,
+        json_payload=None,
+        **kwargs
+    ) -> Response:
         """Send a POST request."""
         return self.session.request(
             'POST',
@@ -116,40 +129,43 @@ class API:
         )
 
     @handle_api_errors
-    def put(self, url: str, data=None, **kwargs) -> requests.Response:
+    def put(self, url: str, data=None, **kwargs) -> Response:
         """Send a PUT request."""
-        return self.session.request('PUT', self.api_endpoint + url, data=data, **kwargs)
+        endpoint = f'{self.api_endpoint}{url}'
+        return self.session.request('PUT', endpoint, data=data, **kwargs)
 
     @handle_api_errors
-    def patch(self, url: str, data=None, **kwargs) -> requests.Response:
+    def patch(self, url: str, data=None, **kwargs) -> Response:
         """Send a PATCH request."""
-        return self.session.request('PATCH', self.api_endpoint + url, data=data, **kwargs)
+        endpoint = f'{self.api_endpoint}{url}'
+        return self.session.request('PATCH', endpoint, data=data, **kwargs)
 
     @handle_api_errors
-    def delete(self, url: str, **kwargs) -> requests.Response:
+    def delete(self, url: str, **kwargs) -> Response:
         """Send a DELETE request."""
-        return self.session.request('DELETE', self.api_endpoint + url, **kwargs)
+        endpoint = f'{self.api_endpoint}{url}'
+        return self.session.request('DELETE', endpoint, **kwargs)
 
-    def _check_token(self, response: requests.Response, *_args, **_kwargs) -> None:
+    def _check_token(self, response: Response, *_args, **_kwargs) -> None:
         """
         Update the local token to a token returned by a server.
 
-        When a server responds to a request, the server can return a newly updated
-        token. The new token could be in response to new information stored within
-        the token, or the token age might be getting close to the expiry time and a
-        token refresh is needed. For more information on bearer tokens, please
-        refer to `bearer tokens <https://datatracker.ietf.org/doc/html/rfc6750>`.
+        When a server responds to a request, the server can return a
+        newly updated token. The new token could be in response to new
+        information stored within the token, or the token age might be
+        getting close to the expiry time and a token refresh is needed.
+        For more information on bearer tokens, please refer to
+        `bearer tokens <https://datatracker.ietf.org/doc/html/rfc6750>`.
 
-        This method checks if a updated token has been returned and stores it in
-        the preferences system for future requests if the token is valid.
+        This method checks if a updated token has been returned and
+        stores it in the preferences system for future requests if the
+        token is valid.
 
-        This function is called as a requests hook. For more information about how
-        to use request hooks, please refer to `Request Hooks
-        <https://docs.python-requests.org/en/master/user/advanced/#event-hooks>`.
+        This function is called as a requests hook.
         """
         try:
             json_data = response.json()
-        except JSONDecodeError:
+        except json.JSONDecodeError:
             return
 
         if 'token' not in json_data:
@@ -161,7 +177,10 @@ class API:
             data[self.region]['token'] = json_data['token']
 
     def fetch_endpoints(self) -> Dict[str, Any]:
-        """Fetch the Area28 endpoint list and return the decoded JSON to the calling method."""
+        """Fetch the Area28 endpoint list.
+
+        Returns the decoded JSON to the calling method.
+        """
         req = self.session.get(self.ENDPOINTS_URL, allow_redirects=True)
         try:
             regions = json.loads(req.content)
@@ -174,7 +193,8 @@ class API:
 
 def get_package(region: str, identifier: str) -> Union[Dict[str, Any], None]:
     """Retrieve a package from the API."""
-    log.debug(f'retrieving package: {{"region": {region}, "identifier": {identifier}}}')
+    response = f'{{"region": {region}, "identifier": {identifier}}}'
+    log.debug(f'retrieving package: {response}')
 
     api = API(region)
     config = ConfigFile.load()
@@ -191,7 +211,12 @@ def get_package(region: str, identifier: str) -> Union[Dict[str, Any], None]:
         raise
 
 
-def register_package(region: str, scope: str, name: str, schema: str) -> Union[str, None]:
+def register_package(
+    region: str,
+    scope: str,
+    name: str,
+    schema: str
+) -> Union[str, None]:
     """Create a package with the API and returns the new uuid."""
     log.debug(f'creating package: {{"region": {region}, "name": {name}}}')
 
@@ -215,12 +240,11 @@ def register_package(region: str, scope: str, name: str, schema: str) -> Union[s
 
 
 def status(args: Namespace) -> None:
-    """
-    Display the status of an endpoint.
+    """Display the status of an endpoint.
 
-    Submit an options request to an api endpoint to check if the endpoint
-    returns a 200 or a 304 status response message with a JSON payload that has
-    a status response and a StatusCode set.
+    Submit an options request to an api endpoint to check if the
+    endpoint returns a 200 or a 304 status response message with a JSON
+    payload that has a status response and a StatusCode set.
     """
     api = API(args.endpoint)
     try:
@@ -246,8 +270,7 @@ def find_or_create_package(
     name: Union[str, None] = None,
     identifier: Union[str, None] = None,
 ) -> Union[str, None]:
-    """
-    Find or create a package and returns its UUID.
+    """Find or create a package and returns its UUID.
 
     if an identifier is provided we'll retrieve it from the API.
     Else we'll create it.
