@@ -3,8 +3,11 @@ import json
 import os
 import zipfile
 from argparse import _SubParsersAction
+
 from a28 import utils
 
+PKG_FILE = 'package.json'
+
 
 def add_build_parser(parser: _SubParsersAction):
     """Create the CLI parser for 'build' command."""
@@ -31,15 +34,14 @@ def build(args):
 
 
 def package(src, dest, meta):
-    """
-    Build an a28 package from the provided src directory.
+    """Build an a28 package from the provided src directory.
 
-    The package will be saved to the dest directory. A package needs to be provided containing
-    at least an identifier and a version number.
+    The package will be saved to the dest directory. A package needs to
+    be provided containing at least an identifier and a version number.
     """
     version = meta['version']
     identifier = meta['identifier']
-    filename = '{}-{}.{}'.format(identifier, version, 'a28')
+    filename = f'{identifier}-{version}.a28'
     filename = os.path.join(dest, filename)
 
     os.makedirs(dest, exist_ok=True)
@@ -60,17 +62,16 @@ def package(src, dest, meta):
 
 
 def get_info(src, extracted=False):
-    """
-    Get information about a package.
+    """Get information about a package.
 
-    Using the package.json file located within the packages directory, fetch
-    the information about the package including the version number and
-    identifier.
+    Using the package.json file located within the packages directory,
+    fetch the information about the package including the version number
+    and identifier.
     """
     if extracted:
         data = json.load(src)
     else:
-        package_config = os.path.join(src, 'package.json')
+        package_config = os.path.join(src, PKG_FILE)
         with open(package_config) as package_data:
             data = json.load(package_data)
     return data
@@ -79,6 +80,6 @@ def get_info(src, extracted=False):
 def extract_meta(pkg):
     """Extract the meta information from a packaged package."""
     with zipfile.ZipFile(pkg) as zf:
-        package_config = next(x for x in zf.namelist() if x.endswith('package.json'))
+        package_config = next(x for x in zf.namelist() if x.endswith(PKG_FILE))
         with zf.open(package_config) as index:
             return get_info(index, True)
