@@ -2,6 +2,7 @@
 import json
 import os
 from typing import Any, Dict
+
 from a28 import utils
 
 
@@ -12,10 +13,10 @@ class ConfigError(Exception):
 
 
 class ConfigFile:
-    """
-    Handles the config file storing token, endpoints and configs.
+    """Handles the config file storing token, endpoints and configs.
 
-    `_save` is 'private' so that we're force to use ConfigFile as a context manager to load/save
+    `_save` is 'private' so that we're force to use ConfigFile as a
+    context manager to load/save.
     """
 
     def __enter__(self) -> Dict[str, Any]:
@@ -29,10 +30,10 @@ class ConfigFile:
 
     @staticmethod
     def get_token(region: str) -> str:
-        """
-        Retrieve the token from config.
+        """Retrieve the token from config.
 
-        Load configuration information and return the token for the given region
+        Load configuration information and return the token for the
+        given region.
         """
         config = ConfigFile.load()
 
@@ -45,7 +46,7 @@ class ConfigFile:
     def load() -> Dict[str, Any]:
         """Load configuration information if information exists."""
         try:
-            with open(utils.get_current_config_path()) as json_file:
+            with open(utils.CONFIG) as json_file:
                 data = json.load(json_file)
             return data
         except OSError:
@@ -59,8 +60,8 @@ class ConfigFile:
         content = json.dumps(data, indent=4)
 
         # create the config path if it doesn't exist
-        os.makedirs(utils.get_current_config_dir(), exist_ok=True)
+        os.makedirs(utils.CONFIG_PATH, exist_ok=True)
 
         # save the configuration data to file
-        with open(utils.get_current_config_path(), 'w') as config:
+        with open(utils.CONFIG, 'w') as config:
             config.write(content)
