@@ -1,21 +1,22 @@
 """Manage package creation, building, and submitting.
 
-The package module provides a set of utilities designed for package developers
-to create packages, build packages from python source code, and submit packages
-to be included in the list of installable packages within Area28.
+The package module provides a set of utilities designed for package
+developers to create packages, build packages from python source code,
+and submit packages to be included in the list of installable packages
+within Area28.
 """
 import hashlib
 import json
 import os
 import shutil
 from argparse import Namespace
+
 from a28 import log, utils
 from a28.api import API, find_or_create_package
 from a28.build import add_build_parser, extract_meta
 from a28.config import ConfigFile
 from a28.publish import add_publish_parser
 
-
 package_types = [
     'api',
     'app',
@@ -34,7 +35,11 @@ package_types = [
 
 def cli_options(main_parser):
     """Argparse options added to the cli."""
-    parser = main_parser.add_parser('package', aliases=['pkg'], help='package actions')
+    parser = main_parser.add_parser(
+        'package',
+        aliases=['pkg'],
+        help='package actions'
+    )
     package_parser = parser.add_subparsers(
         dest='package',
         required=True,
@@ -114,7 +119,7 @@ def add_init_parser(parser_init):
         '-i',
         '--identifier',
         required=False,
-        help='provide a pre-registered identifier (defaults to getting one from API)',
+        help='provide a pre-registered identifier (defaults to API value)',
     )
     parser_init.add_argument(
         '--bin',
@@ -170,7 +175,7 @@ def generate_jsondata(scope, name, schema, identifier, args):
     """Generate a basic package.json data."""
     json_data = {
         'name': f'@{scope}/{name}',
-        'description': f'{schema} package created using the A28 command by {scope}.',
+        'description': f'{schema} package created using A28 cmd by {scope}.',
         'version': '0.1.0',
         'identifier': identifier,
     }
@@ -244,11 +249,11 @@ def install(args):
     meta = extract_meta(args.pkg)
     meta['hash'] = pkg_hash
     install_local(args.pkg, meta)
-    utils.message('installed {}'.format(meta['name']))
+    utils.message(f'installed {meta["name"]}')
 
 
 def install_local(pkg, meta):
-    """Install a package locally by calling the update_index function."""
+    """Install package locally by calling the update_index function."""
     dest = os.path.join(utils.STORAGE, 'cache')
     shutil.copy(pkg, dest)
     index = os.path.join(utils.STORAGE, 'index.json')
@@ -259,7 +264,7 @@ def install_local(pkg, meta):
 def update_index(index_data, meta):
     """Update the index.json without touching the etag.json file.
 
-    This will be overwritten when a new official index.json is published.
+    This will be overwritten when new official index.json is published.
     """
     data = json.load(index_data)
     data['packages'][meta['name']] = meta
@@ -302,9 +307,9 @@ def _build_structure(path, subdirs):
 def get_info(src, extracted=False):
     """Get information about a package.
 
-    Using the package.json file located within the packages directory, fetch
-    the information about the package including the version number and
-    identifier.
+    Using the package.json file located within the packages directory,
+    fetch the information about the package including the version number
+    and identifier.
     """
     if extracted:
         data = json.load(src)
